/*
 *  Remote Network application system for DNAS
 *  Copyright (C) 2002 Junichi Uekawa
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: rnas-dump.c,v 1.6 2002/08/08 09:02:22 dancer Exp $
 */

#define _GNU_SOURCE
#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <unistd.h>
#include <pthread.h>
#include "config.h"
#include "dmachinemon/dmachinemon-debug.h"
#include "dmachinemon/dmachinemon.h"
#include "dmachinemon/libsocket.h"
#include "dmachinemon/dmachinemon-libdatabase.h"
#include "dmachinemon/dmachinemon-commandlineparser.h"

#define PROGRAMNAME "rnas-dump"

static void access_master(const char * hostname, const char* portnumber)
{
  int fd = dm_connect_to_host(hostname, atoi(portnumber));
  FILE* f=(fd!=-1)?fdopen (fd, "r"):NULL;
  
  if (!f)
    {
      fprintf (stderr, PROGRAMNAME ": cannot open server socket\n");
      exit(1);
    }

  if (dm_process_nodes_input (f, &maininfo, NULL, NULL))
    {
      fprintf (stderr, PROGRAMNAME ": could not handle input...\n");
      exit (1);
    }  

  fclose(f);
}

static void
rnas_dump_printhelp(void)
{
  fprintf(stderr, 
	  "RNAS dump application, Copyright (c)2002 Junichi Uekawa.\n\n"
	  "\trnas-dump [DNAS options] -- [dump parameter]\n"
	  "Please specify dump parameter\n\n\n"
	  );
  dmachinemon_print_commandline_help();      
}

static void
iterate_database_for_searchstrings(dm_machinelist * a, char ** search_string)
{
  const char * buf;
  int i=0;
  
  while (search_string[i])
    {
      buf = dm_get_value_text(a, search_string[i]);
      if (buf)
	printf ("%s ", buf);
      i++;
    }
}


static void
iterate_database(dm_machinelist * a, char ** search_string)
{
  if (!a)
    {
      printf ("zero info found");
      return ;      
    }
  
  
  for ( ; a; a=a->next)  
    {
      printf ("%s: ", a->machinename);
      
      iterate_database_for_searchstrings(a, search_string);
      printf ("\n");
    }
}

int
main(int ac, char ** av)
{
  dm_commandoption cdat;
  dmachinemon_parse_options(ac, av, &cdat);
  if (!cdat.parenthostname)
    {
      rnas_dump_printhelp();
      exit(1);
    }
  access_master (cdat.parenthostname, cdat.port_client);
  
  if (!av[optind])
    {
      rnas_dump_printhelp();
      exit(1);
    }

  iterate_database(maininfo.machinedb, &av[optind]);
  
  exit(0);
}

